# dopynion

Dominion in Python

## TODO

- limiter le graphe en nombre de jours
- logger dans les last games les résultats des hooks
- gérer les exceptions dans les hooks et la désactivation des joueurs (y compris dans other_players)
- dans le site, mettre l'ordre des joueurs en fonction du score dans les anciennes parties
- checker les identifiants de partie renvoyés par les API
- s'assurer que les stratégies random fonctionnent avec des parties en simultané
- afficher les noms des équipes sur le leader board et le graphe
- purger les anciens games automatiquement sur le serveur
